==> jquery-packir-0.1.9.tgz: package/example/example.js <==
void function() {
    images.forEach(function(def, index) {
        var $el, width, height, color, padding;

        padding = 5;

        switch (Math.random() > 0.85) {
            case true: {
                width = 150;
                height = 150;
                break;
            }

            case false: {
                width = 75;
                height = 75;
                break;
            }
        }

        color = '#' + (((Math.random() + 1) * (1 << 24)) | 0).toString(16).substr(1);

        $el = $("<div/>")
            .css({
                width: width + 'px',
                height: height + 'px',
                background: color,
                position: 'relative',
                overflow: 'hidden'
            })
            .addClass('pkr-img');

        $el.append($("<div/>").addClass("pkr-hover").html(index).css({
            width: width + 'px',
            height: height + 'px',
            'line-height': height + 'px'
        }));

        $el.append(
            $("<img/>")
                .attr({src: def.src})
                .css({
                    position: 'absolute',
                    left: ((width + padding * 2) - def.size.width) / 2,
                    top: ((height + padding * 2) - def.size.height) / 2
                })
        );

        $("#main").append($el);
    });

    function debounce(fn, wait) {
        var id;

        return function() {
            clearTimeout(id);
            id = setTimeout(fn, wait);
        }
    }

    function packir() {
        var start = Date.now(),
            proportion;

        proportion = {
            width: {
                75:  2,
                150: 1
            }
        };

        $("#main")
            .packir({
                strategy: "base",
                compressor: "stack",
                rules: [
                    [ "nonrecurring-y", { width: {150: 0} } ],
                    [ "nonrecurring-x", proportion ],
                    [ "recurring-x", proportion ]
                ],
                options: {
                    margin: {
                        x: 4,
                        y: 4,
                        cut: true
                    }
                },
                callback: function(err) {
                    if (err) {
                        console.error(err);
                        return;
                    }

                    console.log('duration', Date.now() - start);
                }
            });
    }

    $(window).on("resize", debounce(packir, 50));

    packir();
}();

==> jquery-packir-0.5.0.tgz: package/example/example.js <==
void function() {
    images.forEach(function(def, index) {
        var $el, width, height, color, padding;

        switch (Math.random() > 0.85) {
            case true: {
                width = 160;
                height = 160;
                break;
            }

            case false: {
                width = 75;
                height = 75;
                break;
            }
        }

        color = '#' + (((Math.random() + 1) * (1 << 24)) | 0).toString(16).substr(1);

        $el = $("<div/>")
            .css({
                width: width + 'px',
                height: height + 'px',
                background: color,
                position: 'relative',
                overflow: 'hidden'
            })
            .data({
                width: width,
                height: height
            })
            .addClass('pkr-img');

        $el.append($("<div/>").addClass("pkr-hover").html(index).css({
            width: width + 'px',
            height: height + 'px',
            'line-height': height + 'px'
        }));

        $el.append(
            $("<img/>")
                .attr({src: def.src})
                .css({
                    position: 'absolute',
                    left: ((width) - def.size.width) / 2,
                    top: ((height) - def.size.height) / 2
                })
        );

        $("#main").append($el);
    });

    function debounce(fn, wait) {
        var id;

        return function() {
            clearTimeout(id);
            id = setTimeout(fn, wait);
        }
    }

    function packir() {
        var start = Date.now();

        $("#main")
            .packir({
                strategy: "base",
                compressor: "stack",
                rules: [
                    ["nonrecurring-y", {
                        width: {
                            160: 50
                        }
                    }],
                    ["nonrecurring-x", {
                        width: {
                            75:  3,
                            160: 1
                        }
                    }],
                    ["recurring-x", {
                        width: {
                            75:  2,
                            160: 1
                        }
                    }],
                    ["preferred-size", {
                        width: 160
                    }]
                ],
                store: {
                    ttl: 1000 * 60 * 60 * 24
                },
                options: {
                    margin: {
                        x: 10,
                        y: 10,
                        cut: false
                    }
                },
                callback: function(err) {
                    if (err) {
                        console.error(err);
                        return;
                    }

                    console.log('duration', Date.now() - start);
                }
            });
    }

    $(window).on("resize", debounce(packir, 50));

    packir();
}();
